require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_xtokenize',
  dscmeta_resource_friendly_name: 'xTokenize',
  dscmeta_resource_name: 'MSFT_xTokenize',
  dscmeta_resource_implementation: 'MOF',
  dscmeta_module_name: 'xReleaseManagement',
  dscmeta_module_version: '1.0.0.0',
  docs: 'The DSC xTokenize resource type.
         Automatically generated from version 1.0.0.0',
  features: ['simple_get_filter', 'canonicalize', 'custom_insync'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    validation_mode: {
      type:      'Enum[property, resource]',
      desc:      'Whether to check if the resource is in the desired state by property (default) or using Invoke-DscResource in Test mode (resource).',
      behaviour: :parameter,
      default:   'property',
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_usetokenfiles: {
      type: 'Optional[Boolean]',
      desc: 'A flag indicating if a token file is provided.  Tokenization can occur with or without a token file. The default value is true',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_searchpattern: {
      type: 'Optional[String]',
      desc: "Defines the pattern to use when searching for files. The default value is '*.*'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'Path under which a search will be performed to locate files to transform.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_tokens: {
      type: 'Optional[Array[Struct[{
              key => Optional[String],
              value => Optional[String],
            }]]]',
      desc: 'A hash table of tokens with their values.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'MSFT_KeyValuePair[]',
      mof_is_embedded: true,
    },
    dsc_recurse: {
      type: 'Optional[Boolean]',
      desc: 'A flag to indicate if a recursive search of the path should be performed. The default value is false.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
